@@ -1,10 +1,10 @@
 /*
 *****************************************************************************
 *
-* Copyright (c) 2009 - 2019 Teunis van Beelen
+* Copyright (c) 2009, 2010, 2011, 2012, 2013, 2014, 2015 Teunis van Beelen
 * All rights reserved.
 *
-* Email: teuniz@protonmail.com
+* email: teuniz@gmail.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
@@ -51,7 +51,7 @@ void remove_trailing_zeros(char *);
 
 
 
-int main(void)
+int main(int argc, char *argv[])
 {
   int i, j,
       hdl,
@@ -211,16 +211,6 @@ int main(void)
 
   freqspan = stopfreq - startfreq;
 
-  if(linear)
-  {
-    freq = startfreq + (freqspan * ((double)sampleswritten / (double)samples));
-  }
-  else
-  {
-    // freq = expo((((double)sampleswritten / (double)samples)) * log10(stopfreq));
-    freq = expo(((((startfreq / stopfreq) * ((stopfreq / freqspan) * samples)) + sampleswritten) / ((stopfreq / freqspan) * samples)) * log10(stopfreq));
-  }
-
   for(j=0; j<fileduration; j++)
   {
     for(i=0; i<smp_freq; i++)
